## Description
Description claire des changements apportés.

## Type de changement
- [ ] Bug fix (changement non-cassant qui corrige un problème)
- [ ] Nouvelle fonctionnalité (changement non-cassant qui ajoute des fonctionnalités)
- [ ] Changement cassant (fix ou fonctionnalité qui casserait les fonctionnalités existantes)
- [ ] Documentation seulement
- [ ] Performance (amélioration des performances)
- [ ] Refactoring (changement de code sans impact fonctionnel)

## Motivation et contexte
Pourquoi ce changement est-il nécessaire ? Quels problèmes résout-il ?

Fixes #(numéro d'issue)

## Comment cela a-t-il été testé ?
- [ ] Tests unitaires existants passent
- [ ] Nouveaux tests unitaires ajoutés
- [ ] Tests d'intégration exécutés
- [ ] Tests manuels effectués
- [ ] Tests de performance exécutés

**Configuration de test** :
- OS: 
- Python: 
- Backend: 

## Checklist
- [ ] Mon code suit les standards du projet
- [ ] J'ai effectué une revue de mon propre code
- [ ] J'ai commenté les parties complexes
- [ ] J'ai mis à jour la documentation si nécessaire
- [ ] Mes changements ne génèrent pas de nouveaux warnings
- [ ] J'ai ajouté des tests qui prouvent que mon fix est efficace ou que ma fonctionnalité marche
- [ ] Les tests unitaires nouveaux et existants passent en local
- [ ] Tous les changements dépendants ont été mergés et publiés

## Impact sur les performances
- [ ] Aucun impact
- [ ] Amélioration des performances
- [ ] Régression possible (justifiée ci-dessous)

## Changements cassants
- [ ] Aucun changement cassant
- [ ] Changements cassants (listés ci-dessous)

**Liste des changements cassants** :
1. 
2. 

## Captures d'écran (si applicable)

## Notes pour les reviewers
Points particuliers à vérifier ou contexte supplémentaire.